var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
import { styled, css } from "solid-styled-components";
import { init, registerCallback } from "@bedrock-layout/register-resize-callback";
import { createSignal, onMount, createEffect, onCleanup, Switch, Match } from "solid-js";
function checkIsCSSLength(str) {
  if (typeof str !== "string")
    return false;
  return [
    /^[0-9]{0,10000}\.?[0-9]{1,10000}(vmin|vmax|vh|vw|%|ch|ex|em|rem|in|cm|mm|pt|pc|px)$/,
    /^var\(--\D{1,100}\)$/
  ].some((regex) => regex.test(str));
}
const spacing = {
  none: "0px",
  xxs: "0.0625rem",
  xs: "0.125rem",
  sm: "0.25rem",
  md: "0.5rem",
  mdLg: "0.75rem",
  lg: "1rem",
  lgXl: "1.5rem",
  xl: "2rem",
  xlXXl: "3rem",
  xxl: "4rem"
};
function fromEntries(entries) {
  return entries.reduce((acc, [key, value]) => {
    return __spreadProps(__spreadValues({}, acc), { [key]: value });
  }, {});
}
const getSpacingValue = (spacingKey, theme) => {
  var _a, _b;
  const maybeSpaceingOrDefault = (_b = (_a = theme == null ? void 0 : theme.space) != null ? _a : theme == null ? void 0 : theme.spacing) != null ? _b : spacing;
  const safeSpacings = fromEntries(Object.entries(maybeSpaceingOrDefault).map(([spaceKey, value]) => [
    spaceKey,
    typeof value === "number" ? `${value}px` : value
  ]));
  const spacingVal = safeSpacings[spacingKey];
  const isCSSLength = checkIsCSSLength(spacingVal);
  return isCSSLength ? spacingVal : void 0;
};
function getSafeMaxWidth(maxWidth) {
  if (maxWidth === void 0)
    return "100%";
  if (typeof maxWidth === "number")
    return `${maxWidth}px`;
  return maxWidth;
}
const Center = styled.div`
  @property --maxWidth {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 100%;
  }

  --maxWidth: ${(props) => getSafeMaxWidth(props.maxWidth)};

  box-sizing: content-box;

  && {
    margin-inline-start: auto;
    margin-inline-end: auto;
    margin-inline: auto;
  }

  max-inline-size: var(--maxWidth, 100%);

  ${(props) => props.centerChildren ? css`
          display: flex;
          flex-direction: column;
          align-items: center;
        ` : ""}

  ${(props) => props.centerText ? css`
          text-align: center;
        ` : ""}
`;
function getSafeBasis(basis) {
  if (basis === void 0)
    return "100%";
  if (typeof basis === "number")
    return `${basis}px`;
  return basis;
}
const ColumnDrop = styled("div")`
  @property --basis {
    syntax: "<length-percentage>";
    inherits: true;
    initial-value: 100%;
  }

  @property --gutter {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 0px;
  }

  --basis: ${(props) => getSafeBasis(props.basis)};
  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};

  box-sizing: border-box;
  > * {
    margin: 0;
    flex-basis: var(--basis, 100%);
    flex-grow: ${(props) => props.noStretchedColumns ? "0" : "1"};
    flex-shrink: 1;
  }

  display: flex;
  flex-wrap: wrap;
  gap: var(--gutter, 0px);
`;
function createContainerQuery(width = 1, maxWidth) {
  if (maxWidth !== void 0 && maxWidth <= width) {
    throw new Error(`The second width value, ${maxWidth}, is not larger than ${width}. Please provide a value greater than first width value`);
  }
  const [matches, setMatch] = createSignal(false);
  const [node, nodeRef] = createSignal();
  onMount(() => {
    init();
  });
  createEffect(() => {
    const ref = node();
    if (ref === void 0 || ref === null)
      return;
    const cleanup = registerCallback(ref, (entry) => {
      var _a, _b;
      const nodeWidth = (_b = (_a = entry.borderBoxSize) == null ? void 0 : _a.inlineSize) != null ? _b : entry.contentRect.width;
      if (nodeWidth > 0) {
        const newMatch = maxWidth === void 0 ? nodeWidth <= width : nodeWidth >= width && nodeWidth <= maxWidth;
        setMatch(newMatch);
      }
    });
    onCleanup(cleanup);
  });
  return [matches, nodeRef];
}
function checkIsRatio(ratio) {
  const isCorrectArray = Array.isArray(ratio) && ratio.length === 2 && ratio.every(Number.isFinite);
  return isCorrectArray || typeof ratio === "string" && /^\d{1,1000} {0,1}\/ {0,1}\d{1,1000}$/.test(ratio);
}
function getRatioString(ratio) {
  return Array.isArray(ratio) ? ratio.join("/") : ratio;
}
function getSafeRatio(ratio) {
  const isRatio = checkIsRatio(ratio);
  return isRatio ? getRatioString(ratio) : void 0;
}
const Frame = styled.div`
  box-sizing: border-box;
  display: block;
  inline-size: 100%;
  position: relative;
  overflow: hidden;

  ${(props) => {
  const maybeRatio = getSafeRatio(props.ratio);
  if (maybeRatio) {
    return css`
        aspect-ratio: ${maybeRatio};
      `;
  }
  return "";
}};

  > * {
    position: absolute;

    inset-block-start: 0;
    inset-block-end: 0;
    inset-inline-start: 0;
    inset-inline-end: 0;

    inset-block: 0;
    inset-inline: 0;

    display: flex;
    justify-content: center;
    align-items: center;
  }

  > :is(img, video) {
    inline-size: 100%;
    block-size: 100%;
    size: 100%;

    object-fit: cover;
    object-position: ${(props) => typeof props.position === "string" ? props.position : "50%"};
  }
`;
const Grid = styled("div")`
  @property --gutter {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 0;
  }

  @property --minItemWidth {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 639px;
  }

  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};
  --minItemWidth: ${(props) => {
  var _a;
  return typeof props.minItemWidth === "string" ? props.minItemWidth : `${(_a = props.minItemWidth) != null ? _a : 0}px`;
}};

  box-sizing: border-box;
  > * {
    margin: 0;
  }

  display: grid;
  gap: var(--gutter, 0px);

  grid-template-columns: repeat(
    auto-fit,
    minmax(min(var(--minItemWidth, 639px), 100%), 1fr)
  );
`;
const justifyMap = {
  start: "flex-start",
  end: "flex-end",
  center: "center"
};
const alignMap = __spreadProps(__spreadValues({}, justifyMap), {
  stretch: "stretch"
});
const InlineCluster = styled.div`
  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};

  box-sizing: border-box;
  > * {
    margin: 0;
  }

  display: flex;
  flex-wrap: wrap;
  gap: var(--gutter, 0px);

  justify-content: ${(props) => typeof props.justify !== "undefined" && justifyMap[props.justify] ? justifyMap[props.justify] : justifyMap.start};

  align-items: ${(props) => typeof props.align !== "undefined" && alignMap[props.align] ? alignMap[props.align] : alignMap.start};
`;
function shouldUseSwitch(switchAt) {
  if (typeof switchAt === "number" && switchAt > -1) {
    return true;
  }
  if (typeof switchAt === "string" && typeof CSS !== void 0) {
    return CSS.supports(`height: ${switchAt}`);
  }
  return false;
}
const Inline = styled(InlineCluster)`
  @property --switchAt {
    syntax: "<length-percentage>";
    inherits: true;
    initial-value: 0;
  }
  flex-wrap: nowrap;
  ${(props) => props.stretch === "all" ? `> *  { flex: 1 }` : props.stretch === "start" ? `> :first-child { flex: 1 }` : props.stretch === "end" ? `> :last-child { flex: 1 }` : typeof props.stretch === "number" ? `> :nth-child(${props.stretch + 1}) { flex: 1 }` : ""}

  ${(props) => shouldUseSwitch(props.switchAt) ? `
          --switchAt: ${typeof props.switchAt === "string" ? props.switchAt : `${props.switchAt}px`};
          flex-wrap: wrap;
          > * {
            min-inline-size: fit-content;
            flex-basis: calc(
              (var(--switchAt) - (100% - var(--gutter, 0px))) * 999
            );
          }
        ` : ""}
`;
const validKeys = /* @__PURE__ */ new Set([
  "left",
  "right",
  "top",
  "bottom",
  "inlineStart",
  "inlineEnd",
  "blockStart",
  "blockEnd"
]);
const keyToProperty = (key, val) => {
  const modernMap = {
    left: `padding-inline-start:${val};`,
    right: `padding-inline-end:${val};`,
    top: `padding-block-start:${val};`,
    bottom: `padding-block-end:${val};`,
    inlineStart: `padding-inline-start:${val};`,
    inlineEnd: `padding-inline-end:${val};`,
    blockStart: `padding-block-start:${val};`,
    blockEnd: `padding-block-end:${val};`
  };
  return modernMap[key];
};
function paddingOrDefault(theme) {
  return (key) => {
    const maybePadding = getSpacingValue(key, theme);
    return maybePadding != null ? maybePadding : "0px";
  };
}
function paddingToString(theme, padding) {
  var _a;
  if (Array.isArray(padding) && padding.length > 4) {
    throw new Error("padding arrays can only be 4 or less in length");
  }
  const validSpacings = new Set(Object.keys((_a = theme == null ? void 0 : theme.spacing) != null ? _a : spacing));
  const isValidPadding = () => {
    if (typeof padding === "string")
      return true;
    if (Array.isArray(padding)) {
      return padding.every((val) => validSpacings.has(val));
    }
    return padding && Object.keys(padding).every((key) => validKeys.has(key)) && Object.values(padding).every((val) => validSpacings.has(val));
  };
  if (!isValidPadding()) {
    console.error("Invalid padding Type");
  }
  const getPadding = paddingOrDefault(theme);
  return typeof padding === "object" && !Array.isArray(padding) ? Object.entries(padding).reduce((acc, [key, val]) => validKeys.has(key) ? acc + keyToProperty(key, getPadding(val)) : acc, "") : padding !== void 0 ? `padding: ${Array.from(Array.isArray(padding) ? padding : [padding]).map((pad) => getPadding(pad)).join(" ")};` : "";
}
const PadBox = styled.div`
  box-sizing: border-box;
  ${(props) => paddingToString(props.theme, props.padding)}
`;
const Reel = styled.div`
  box-sizing: border-box;
  > * {
    margin: 0;
    scroll-snap-align: start;
  }

  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};

  display: flex;
  gap: var(--gutter, 0px);

  overflow-x: scroll;

  scroll-snap-type: ${({ snapType = "none" }) => {
  switch (snapType) {
    case "none": {
      return "none";
    }
    case "proximity": {
      return "x proximity";
    }
    case "mandatory": {
      return "x mandatory";
    }
    default: {
      return "none";
    }
  }
}};
`;
const Stack = styled("div")`
  @property --gutter {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 0;
  }

  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};
  box-sizing: border-box;
  > * {
    margin: 0;
  }
  display: flex;
  flex-direction: column;

  gap: var(--gutter, 0px);
  align-content: start;

  & > [data-bedrock-column] {
    grid-column: span 1 / auto;
  }
`;
const fractions = {
  "1/4": "1fr 3fr",
  "1/3": "1fr 2fr",
  "1/2": "1fr 1fr",
  "2/3": "2fr 1fr",
  "3/4": "3fr 1fr",
  "auto-start": `auto 1fr`,
  "auto-end": `1fr auto`
};
const SplitBase = styled.div`
    box-sizing: border-box;
    > * {
      margin: 0;
    }
    
    --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};
  
    display: grid;
    gap: var(--gutter, 0px);
    grid-template-columns: ${({ fraction = "1/2" }) => {
  var _a;
  return (_a = fractions[fraction]) != null ? _a : fractions["1/2"];
}}};
  `;
const Split = (props) => {
  const maybePx = typeof props.switchAt === "string" ? toPX(props.switchAt) : props.switchAt;
  const widthToSwitchAt = maybePx && maybePx > -1 ? maybePx : 0;
  console.log(widthToSwitchAt);
  const [shouldSwitch, nodeRef] = createContainerQuery(widthToSwitchAt);
  const combineRef = (ref) => {
    var _a;
    nodeRef(ref);
    (_a = props.ref) == null ? void 0 : _a.call(props, ref);
  };
  return /* @__PURE__ */ React.createElement(Switch, null, /* @__PURE__ */ React.createElement(Match, {
    when: shouldSwitch() === false
  }, /* @__PURE__ */ React.createElement(SplitBase, __spreadValues({
    as: props.as,
    ref: combineRef,
    fraction: props.fraction
  }, props))), /* @__PURE__ */ React.createElement(Match, {
    when: shouldSwitch() === true
  }, /* @__PURE__ */ React.createElement(Stack, __spreadValues({
    as: props.as,
    ref: combineRef
  }, props))));
};
function parseUnit(str) {
  var _a;
  str = String(str);
  const num = parseFloat(str);
  const [, unit] = (_a = str.match(/[\d.\-+]*\s*(.*)/)) != null ? _a : ["", ""];
  return [num, unit];
}
function getPropertyInPX(element, prop) {
  var _a;
  const [value, units] = parseUnit(getComputedStyle(element).getPropertyValue(prop));
  return value * ((_a = toPX(units, element)) != null ? _a : 1);
}
function getSizeBrutal(unit, element) {
  const testDIV = document.createElement("div");
  testDIV.style["height"] = "128" + unit;
  element.appendChild(testDIV);
  const size = getPropertyInPX(testDIV, "height") / 128;
  element.removeChild(testDIV);
  return size;
}
function toPX(str, element) {
  if (!str)
    return null;
  const isBrowser = typeof window === "object" && typeof document === "object" && document.nodeType === 9;
  const PIXELS_PER_INCH = isBrowser ? getSizeBrutal("in", document.body) : 96;
  const elementOrBody = element != null ? element : document.body;
  const safeStr = (str != null ? str : "px").trim().toLowerCase();
  switch (safeStr) {
    case "vmin":
    case "vmax":
    case "vh":
    case "vw":
    case "%":
      return null;
    case "ch":
    case "ex":
      return getSizeBrutal(safeStr, elementOrBody);
    case "em":
      return getPropertyInPX(elementOrBody, "font-size");
    case "rem":
      return getPropertyInPX(document.body, "font-size");
    case "in":
      return PIXELS_PER_INCH;
    case "cm":
      return PIXELS_PER_INCH / 2.54;
    case "mm":
      return PIXELS_PER_INCH / 25.4;
    case "pt":
      return PIXELS_PER_INCH / 72;
    case "pc":
      return PIXELS_PER_INCH / 6;
    case "px":
      return 1;
    default: {
      const [value, units] = parseUnit(safeStr);
      if (isNaN(value))
        return null;
      if (!units)
        return value;
      const px = toPX(units, element);
      return typeof px === "number" ? value * px : null;
    }
  }
}
function getSafeMinHeight(minHeight) {
  if (typeof minHeight === "number")
    return `${minHeight}px`;
  return minHeight && checkIsCSSLength(minHeight) ? minHeight : "100vh";
}
const CoverWrapper = styled.div`
  @property --gutter {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 0;
  }

  @property --minHeight {
    syntax: "<length-percentage>";
    inherits: false;
    initial-value: 100vh;
  }

  --gutter: ${(props) => {
  var _a;
  return props.gutter ? (_a = getSpacingValue(props.gutter, props.theme)) != null ? _a : "0px" : "0px";
}};

  --minHeight: ${(props) => getSafeMinHeight(props.minHeight)};

  > * {
    margin: 0;
  }

  display: flex;
  flex-direction: column;
  gap: var(--gutter, 0px);

  min-block-size: var(--minHeight, 100vh);

  > [data-bedrock-cover-centered] {
    margin-block-start: auto;
    margin-block-end: auto;

    ${({ stretchContent }) => stretchContent === true ? `
            flex: 1;
            display: flex;
            flex-direction: column;
            > * {
              flex: 1;
            }
          ` : ""};
  }
`;
const Cover = (props) => {
  const _a = props, { top, bottom, children } = _a, rest = __objRest(_a, ["top", "bottom", "children"]);
  return /* @__PURE__ */ React.createElement(CoverWrapper, __spreadValues({}, rest), props.top, /* @__PURE__ */ React.createElement("div", {
    "data-bedrock-cover-centered": true
  }, props.children), props.bottom);
};
export { Center, ColumnDrop, Cover, Frame, Grid, Inline, InlineCluster, PadBox, Reel, Split, Stack, checkIsCSSLength, createContainerQuery, getSpacingValue, spacing };
